@@ -13,6 +13,13 @@ if PY3:
     unicode = str
     basestring = str
 
+__version__ = '0.5.2'
+__author__ = 'Mahmoud Hashemi'
+__contact__ = 'mahmoudrhashemi@gmail.com'
+__url__ = 'https://github.com/mahmoud/ashes'
+__license__ = 'BSD'
+
+
 # need to add group for literals
 # switch to using word boundary for params section
 node_re = re.compile(r'({'
@@ -298,6 +305,7 @@ def tokenize(source, inline=False):
     tokens = []
     com_nocom = comment_re.split(source)
     line_counts = [1]
+
     def _add_token(t):
         # i wish i had nonlocal so bad
         t.start_line = sum(line_counts)
@@ -906,11 +914,13 @@ def _coerce(value, typestr):
     coerce_type = _COERCE_MAP.get(typestr.lower())
     if not coerce_type or isinstance(value, coerce_type):
         return value
+    if isinstance(value, basestring):
+        try:
+            value = json.loads(value)
+        except (TypeError, ValueError):
+            pass
     try:
-        if isinstance(value, basestring):
-            return coerce_type(json.loads(value))
-        else:
-            return coerce_type(value)
+        return coerce_type(value)
     except (TypeError, ValueError):
         return value
 
@@ -1681,22 +1691,17 @@ def _main():
     # TODO: accidentally unclosed tags may consume
     # trailing buffers without warning
     try:
-        #tpl = FlatteningPathLoader('./_test_tmpls', keep_ext=False)
-        #ashes.loaders.append(tpl)
-        #ashes.load_all()
-        #rendereds = dict([(k, t.render({})) for k, t in ashes.templates.items()])
-
-        tmpl = ('{@eq key=hello value="true" type="string"}{hello}, world'
-                '{:else}oh well, world{/eq} '
-                '{@size key=""/} characters')
+        tmpl = ('{@eq key=hello value="True" type="boolean"}'
+                '{hello}, world'
+                '{:else}'
+                'oh well, world'
+                '{/eq}'
+                ', {@size key=hello/} characters')
         ashes.register_source('hi', tmpl)
-        print(ashes.render('hi', {'hello': True}))
+        print(ashes.render('hi', {'hello': 'greetings'}))
     except Exception as e:
         import pdb;pdb.post_mortem()
         raise
-    else:
-        pass
-        #import pdb;pdb.set_trace()
 
 if __name__ == '__main__':
     _main()
